#
# spec file for package xine-ui
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xine-ui
%bcond_without distributable
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  curl-devel
BuildRequires:  fdupes
BuildRequires:  gawk
BuildRequires:  libjpeg-devel
BuildRequires:  perl-DateTime
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libxine)
%if !%{with distributable}
BuildRequires:  libxine2-codecs
%endif
BuildRequires:  lirc-devel
BuildRequires:  readline-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(xxf86vm)
Summary:        Video player with plugins
License:        GPL-2.0-or-later AND SUSE-Public-Domain
Group:          Productivity/Multimedia/Video/Players
Version:        0.99.14
Release:        2.3
URL:            http://xine.sourceforge.net
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       xine:/usr/bin/xine
Source:         http://sourceforge.net/projects/xine/files/xine-ui/%{version}/xine-ui-%{version}.tar.xz
Source1:        xine-ui.png
Source2:        xine-ui-crippled.png
# extra skins
Source11:       caramel.tar.bz2
Source12:       CelomaChrome.tar.bz2
Source13:       lcd.tar.bz2
Source99:       baselibs.conf
# *** xine-lib: Bugfixes
Patch0:         xine-ui-various.diff
#PATCH_FIX-OPENSUSE xine-ui-desktop.patch davejplater@gmail.com - remove desktop file errors
Patch1:         xine-ui-desktop.patch
# *** SUSE only changes
Patch50:        xine-ui-crippled-LOCAL.diff
Patch60:        xine-ui-AUTOMAKE.diff

%description
xine is a free multimedia player. It plays back CDs, DVDs, and VCDs. It
also decodes multimedia files like AVI, MOV, WMV, and MP3 from local
disk drives, and displays multimedia streamed over the Internet. It
interprets many of the most common multimedia formats available - and
some of the most uncommon formats, too.



Authors:
--------
    Guenter Bartsch <guenter@sourceforge.net>

%prep
echo %{with distributable}
%setup -q
%patch -P 0
%patch -P 50 -p0
%patch -P 60
%patch -P 1
install -m 0644 %SOURCE1 misc/splash-default/xine-ui_logo.png
install -m 0644 %SOURCE2 misc/splash-default/xine-ui_logo-crippled.png
%ifarch x86_64
sed -i -e "s/lirc_libprefix=\"\$LIRC_PREFIX\/lib\"/lirc_libprefix=\"\$LIRC_PREFIX\/lib64\"/g" \
       -e "s/for llirc in \$lirc_libprefix \/lib \/usr\/lib \/usr\/local\/lib; do/for llirc in \$lirc_libprefix \/lib64 \/usr\/lib64 \/usr\/local\/lib64; do/g" m4/_xine.m4
%endif

%build
%if 1 == 0
%define gcc_version 7
export CC=gcc-7
export CPP=cpp-7
export CXX=g++-7
%endif
export CFLAGS="%{optflags} -fno-strict-aliasing"
%if 0%{?gcc_version} > 5
export CFLAGS="$CFLAGS -Werror=date-time"
%endif
# ignore nonupdated automake+co files
rm -f missing ; touch missing
export XINE_DOCPATH=%{_datadir}/doc/packages/xine-ui

NO_CONFIGURE=1 ./autogen.sh

%configure \
	--enable-vdr-keys \
	--with-pic \
	--disable-static \
	--without-aalib \
	--without-caca \
	--without-fb \
	--disable-silent-rules
make %{_smp_mflags} V=1

%install
make install DESTDIR=%{buildroot}
install -d -m755 %{buildroot}%{_defaultdocdir}
mv %{buildroot}%{_datadir}/doc/xitk %{buildroot}%{_defaultdocdir}/xine-ui
mkdir -p %{buildroot}%{_datadir}/applications/
rm -rf %{buildroot}%{_datadir}/xine/desktop
install -m 0644 %SOURCE2 %{buildroot}%{_datadir}/xine/skins/xine-ui_logo-crippled.png
# extra skins
install -d -m755 %{buildroot}%{_datadir}/xine/skins/
for i in %SOURCE11 %SOURCE12 %SOURCE13 ; do
  tar xfvj $i -C %buildroot%{_datadir}/xine/skins/
done
#
%find_lang %{name}
%find_lang xitk %{name}.lang
# delete aaxine man pages as we don't build it
find %{buildroot} -name "aaxine.1*" -print -delete
%fdupes -s %{buildroot}%{_datadir}/xine
%if 0
%fdupes -s %{buildroot}%{_mandir}
%endif

%post
%mime_database_post
%desktop_database_post

%postun
%mime_database_postun
%desktop_database_postun

%files -f %{name}.lang
%defattr(-,root,root,0755)
%dir %_mandir/??
%dir %_mandir/??/man1
%doc %_mandir/*/man1/xine.1.gz
%doc %_mandir/*/man1/xine-check.1.gz
%doc %_mandir/*/man1/xine-remote.1.gz
%doc %_mandir/man1/xine.1.gz
%doc %_mandir/man1/xine-check.1.gz
%doc %_mandir/man1/xine-remote.1.gz
%doc %_mandir/*/man1/xine-bugreport.1.gz
%doc %_mandir/man1/xine-bugreport.1.gz
%{_bindir}/xine
%{_bindir}/xine-check
%{_bindir}/xine-remote
%{_bindir}/xine-bugreport
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%{_datadir}/icons/hicolor/*/apps/xine.png
%{_datadir}/icons/hicolor/scalable/apps/xine.svgz
%dir %{_datadir}/xine
%dir %{_datadir}/xine/skins
%{_datadir}/xine/skins/missing.png
%{_datadir}/xine/skins/xine-ui_logo.mpg
%{_datadir}/xine/skins/xine-ui_logo.png
%{_datadir}/xine/skins/xine-ui_logo-crippled.png
%{_datadir}/xine/skins/xine_64.png
%{_datadir}/xine/skins/xine_splash.png
%{_datadir}/xine/skins/xinetic
%{_datadir}/xine/skins/CelomaChrome
%{_datadir}/xine/skins/caramel
%{_datadir}/xine/skins/lcd
%dir %{_datadir}/xine/visuals
%{_datadir}/xine/visuals/default.mpv
%{_datadir}/applications/xine.desktop
%{_datadir}/xine/oxine
%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/xine-ui.xml
%_defaultdocdir/xine-ui

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Jan 27 2023 Wolfgang Bauer <wbauer@tmo.at>
- Update to 0.99.14
  * Add Dutch translation.
  * Add panel mrl display highlight.
  * Add display flipping support.
  * Better keyboard support.
  * Better status OSD.
  * Better setup, key binding and mediamark editors.
  * Better filename filter.
  * Fix build with libcaca.
  * Fix menu hide.
  * Fix directory add to playlists.
  * Many small fixes and optimizations.
  * Update german translation.
- Drop Fix-build.patch, included in this release
- Disable aalib and directfb support as well. As xine-lib is built
  without them, the corresponding executables (aaxine, fbxine)
  don't work anyway.
* Sat Dec  3 2022 Dave Plater <davejplater@gmail.com>
- Disable CACA support to fix build.
- Don't run fdupes on the man diectory due to link corruption
* Mon Dec 27 2021 wbauer@tmo.at
- Update to 0.99.13
  * Add audio control window.
  * Add some menu shortcuts.
  * Add build optimizations.
  * Better keyboard and mouse wheel support.
  * Improved key binding editor.
  * Massive code cleanup.
  * Massive graphics optimizations.
  * Drop mrl path length limit.
  * Add utf8 and clipboard support for text input fields.
  * Add skin shared pixmap and text position features.
  * Xinetic skin update.
  * Many small fixes and optimizations.
  * Update german translation.
  * Update french translation.
  * Build fixes.
  * Faster build.
  * Separate xitk and X11 stuff pt 1.
- Drop no longer necessary patches:
  * xine-ui-lirc.diff
  * fix-crashes.patch
- Rebase xine-ui-crippled-LOCAL.diff
- Add Fix-build.patch from upstream to fix build failures on arm
  and ppc
* Wed Jun 10 2020 wbauer@tmo.at
- Add fix-crashes.patch to fix crashes when using older skins
* Tue Jan 28 2020 wbauer@tmo.at
- Update xine-ui-crippled-LOCAL.diff to fix a crash when changing
  the skin
* Sun Jan 26 2020 wbauer@tmo.at
- Update to 0.99.12
  * Make XLockDisplay use user switchable.
  * Faster seek.
  * Optimize text rendering.
  * Add utf pixmap support.
  * Add animated logo.
  * Update splash.
  * Fix build with libxine <= 1.2.9.
- Changes in 0.99.11:
  * Offer all autoplay/autodir input plugins.
  * Dont treat hls as playlist.
  * Play ftp:/ mrls instead of downloading.
  * Update german translation.
  * Fix mrl browser background.
  * Fix user agent.
  * Fix libjpeg detection.
  * Fix linking with caca.
  * Fix memory and resource leaks.
  * Fix crashes.
  * Fix lirc build.
  * Code cleanup and "dust removal".
- Rebase xine-ui-crippled-LOCAL.diff and greatly simplify it by
  removing all whitespace changes
- Rebase xine-ui-AUTOMAKE.diff
* Fri Mar  2 2018 crrodriguez@opensuse.org
- Use system's default libpng library, not libpng12
* Tue Feb 27 2018 crrodriguez@opensuse.org
- Remove buildrequires on xorg-x11-devel
* Tue Jan 23 2018 davejplater@gmail.com
- Update to release 0.99.10
- Removed incorporated xine-ui-rpmlintrc.diff and reproducible.patch.
- Rebased xine-ui-AUTOMAKE.diff, xine-ui-desktop.patch and
  xine-ui-crippled-LOCAL.diff.
- Upstream changes:
  * Added manual video single step feature.
  * Show millisecond time in slow motion.
  * Updated spanish translation.
  * Make desktop file output reproducible.
  * Deadlock and crash fixes.
  * Memory and resource leak fixes.
* Wed May  3 2017 bwiedemann@suse.com
- Add reproducible.patch to make build fully reproducible
  by not having variations in mime type order in .desktop file
* Thu Apr 20 2017 davejplater@gmail.com
- Fix desktop file with xine-ui-desktop.patch
* Mon Mar 30 2015 wbauer@tmo.at
- delete xine-ui-array-overflow.diff, it was not applied anyway
  since 0.99.8 because it's included upstream now
* Wed Mar 25 2015 lnussel@suse.de
- add upstream download URL
* Fri Mar  6 2015 wbauer@tmo.at
- update to 0.99.9
  * Handle building using libreadline 6.3 and libcaca 0.99 beta 19.
  * More shutdown fixes.
  * Show DVD & BluRay menu names.
  * More *BSD support – NetBSD, DragonFlyBSD.
* Fri Apr 11 2014 Manfred.Tremmel@iiv.de
- update to 0.99.8
  * Fixed opening file using menus
  * Fixed exit on panel close
  * Fixed deadlocks
  * Fixed segfault at exit
  * Fixed keymap editor deadlock
* Mon Dec 30 2013 Manfred.Tremmel@iiv.de
- added missing supported mime types in desktop file
* Fri Mar  1 2013 coolo@suse.com
- update license to new format
* Mon Jul 30 2012 coolo@suse.com
- just take the default libjpeg
* Fri Jun 15 2012 coolo@suse.de
- cleanup unused patches
* Mon Jun 11 2012 Manfred.Tremmel@iiv.de
- fixed stringcompare problems rpmlint reported
* Sun Jun 10 2012 Manfred.Tremmel@iiv.de
- update to 0.99.7:
  * Support for comments in .m3u playlists
  * Avoid possible overflows when handling media marks & M3U files.
  * Fixes for libpng 1.5 and header checking.
  * xine-bugreport uses $TMPDIR.
  * Spanish translation update from Carlos E. Robinson M.
  * Czech translation update.
  * Use only ASCII for "picture" texts in skin.
  * Fix of the help texts encoding.
  * Avoid a deadlock in the tooltips code.
  * Set combo box menu windows' override-redirect flags.
  * MRL browser recognises a few more extensions.
  * Fix LIRC library detection (build time).
  * Fix a segfault which prevented the display of the help window.
  * Make building of fbxine optional (--with-fb; enabled by default).
  * "ToggleFullscreen" command takes an optional numeric parameter,
    controlling whether full-screen mode is switched on or off.
  * New command "Close".
  * Rename default.avi to default.mpv since it's actually an MPEG.
  * Replace the splash .mpv with a PNG (from xine-lib).
  * Support use of JPEG images for splash etc.
  * Make use of XScreenSaver.
  * Set dialogue windows' maximum sizes.
  * Fix LIRC check so that it doesn't fail if liblircclient0.pc (which is
    Debian-specific) is missing.
  * Recognise "authentication needed" messages from xine-lib 1.2.
  * Handle "file is empty" messages from xine-lib.
  * Add support for XINE_EVENT_MRL_REFERENCE_EXT.
  * Use re-entrant XML parser functions (if available).
  * Distribute xine_splash.xcf (source for xine_splash.png).
  * Tidy up building of common function libraries; ensure all replacement
    function sources are distributed.
  * xine.desktop now says that xine can accept files or URLs.
* Sat Jun  2 2012 Manfred.Tremmel@iiv.de
- deactivated xine-ui-libpng15.diff causes crashes
* Sat May 26 2012 Manfred.Tremmel@iiv.de
- update to 0.99.6:
  * Use pkg-config only; xine-config is deprecated.
  * Fix build with libpng 1.4.
  * Fix build on Mac OS X.
  * Fix segfaults caused by our getline() (only used if no system getline()).
  * Add front-end support for .ass subtitles.
  * Point xine-bugreport at the current bugs list; note the bug tracker URL.
  * Disable character substitution code (xine bug 30). Let's see what breaks...
  * Set menu windows' override-redirect flag (xine bug 24)
  * Automatically load opensubtitle-like filenames <name>.*.<subext>
  * New/updated spanish manpage translations from Carlos E. Robinson
  * Fixed possible corruption and overflow of keybindings table
  * Mark the toolbar window as such; should fix control panel visibility issues
    in full-screen mode with some window managers. [bug SF 1750100]
  * New command/keybinding from Richard van Paasen:
    "PVRSetFrequency" changes frequency on ivtv cards (input_pvr).
  * Install a shared-mime-info entry for .tox files, contributed by
    Peter Fox in bug #10.
  * New commands/keybindings from Richard van Paasen:
    "PVRSetInput" changes input on ivtv cards (input_pvr);
    "PVRSetMark", "PVRSetName", "PVRSave" enable saving
    of live streams from ivtv cards (input_pvr).
  * New command/keybinding from Richard van Paasen:
    "SetPosition100%%" jumps to end of stream.
  * Recognize .rmvb files, closes debian bug #437864.
  * Recognize .m2p files, closes debian bug #419002.
  * Fixes for stdctl race conditions, contributed by Stas Sergeev
  * Resetting the video controls restores the driver default settings
    instead of fixed center values
  * New commands/keybindings from Stas Sergeev:
    "SelectMrl" with a numeric parameter allows to select an MRL directly
    by its position number in the playlist.
    "KeyBindingsEnable" with optional numeric parameter allows to enable/disable
    the keybindings (disabled by param equal to 0, else enabled), so stdctl can
    get exclusive control over the keys with disabled bindings; this command is
    not bound to a key by default for an obvious reason (don't dare to bind) ;-)
  * Enhanced commands/keybindings with contributions from Stas Sergeev:
    "PlaylistStop" accepts a numeric parameter to set the stop state absolutely
    (continue if param equals 0, else stop) and persistent, i.e. not reset to
    "continue" after playing current stream, as opposed to the usual toggling
    without parameter; usual toggling is now also possible when no stream is
    currently played, allowing to change the selection at any time.
    "ToggleLoopMode" and "ToggleAspectRatio" accept a numeric parameter as index
    to make a direct selection from the list of their possible states
  * Stdctl enhancements and fixes from Stas Sergeev:
    Feedback messages and echoing of key presses to standard output added,
    clean exit upon closing standard input connection or quitting xine-ui,
    multiple commands in one command string handled
  * Fixed wrong locale path (introduced in previous release) and related crash
    concerning tooltips, closes debian bug #432798.
  * ASCII Art updates:
  * fixed aalib detection in configure
  * build with libcaca >= 0.99, fixes xine bug #50
  * update CACA output due to changes in xine-lib
  * Various memleak and memory access fixes, for example:
  * skin downloader crash
  * cleaner destroy of the widgets in xine toolkit ("kamikaze patch")
  * proper free after strsep()
  * opening multiple times TV settings window
  * Fixed string encoding conversion, closes xine bug #14.
  * Fixed loading of playlist containing relative paths, closes xine bug #52,
    save old playlist with absolute paths on exit.
  * Fixed possible integer overflow when parsing PNG files in skins, closes
    xine bug #153.
  * Lock display on exit, xine bug #193.
  * Drag & drop race condition fixes.
- build against xine-lib 1.2 not 1.1
* Mon Jan  9 2012 pgajdos@suse.com
- build also against libpng15
  * libpng15.patch
* Thu Sep 29 2011 lnussel@suse.de
- add missing -lpthread and -lXext to LDFLAGS
- fix an (harmless) array overflow
* Thu Aug 11 2011 aj@suse.de
- Remove inclusion of <curl/types.h>, it's obsolete in curl since
  2004.
* Thu May 12 2011 mhopf@novell.com
- Fix path to help directory (bnc #680277)
* Sun Apr  4 2010 ro@suse.de
- fix build with libpng14 (png_check_sig replaced by png_sig_cmp)
* Sun Nov 15 2009 meissner@suse.de
- refreshed patches with fuzz=0
* Mon May 25 2009 lnussel@suse.de
- lirc -> lirc-devel in BuildRequires
* Fri Sep 26 2008 mhopf@suse.de
- Fix broken locale support.
* Fri Aug 22 2008 lnussel@suse.de
- include skins previously contained in xine-extra package
* Tue Feb 26 2008 crrodriguez@suse.de
- use find_lang macro
* Tue Jan 29 2008 lnussel@suse.de
- fix path to logo image
* Fri May  4 2007 mhopf@suse.de
- Update to 0.99.5:
  * Included many patches upstream
  * Updated language translations.
  * Handle audio amp level event.
  * Further VDR keys added.
  * Harmonized appearance of non-skinned windows with more space
  * Shortcut keys unused in a particular window work transparent now,
    i.e. as configured by their key bindings
  * Added support for gnome screen saver
  * Fixes and improvements for appearance and behaviour
  * Video window: User magnification ignored and auto-resizing on new stream
    maintained in background if not in visible windowed mode.
  * Improved positioning of menu windows and menu navigation by keyboard
  * OSD improvements in xitk
  * followed freedesktop standards (desktop file and icons)
  * support gapless playback while switching streams (requires xine-lib >= 1.1.1)
  * Many additional fixes and enhancements ...
* Mon Jan 15 2007 mhopf@suse.de
- Update of formatstrings security fix.
* Fri Jan 12 2007 mhopf@suse.de
- Security: Fix multiple missing "%%s" formatstrings. #233516
* Wed Oct 11 2006 mhopf@suse.de
- Fixed for building w/o automake.
- Spec file cleanup.
* Tue Oct 10 2006 mhopf@suse.de
- Fixed detection of crippled package for general playback (mpeg2 + ffmpeg).
* Wed Sep 27 2006 lnussel@suse.de
- build package separate from xine-lib
